#!/bin/sh

# description: Start/Stop roulettemaster
#
# This file belongs in /etc/init.d where it will be run
# on system startup and shutdown to start the roulettemaster
# This program is used for repairing the database file, every
# bootup.


# This init script contains functions specific for redhat
# and mandrake init scripts.

# Source function library.
. /etc/rc.d/init.d/functions

export eSRV_LOG_FILE_PATH=/data/cbLogFile.log

export eSRV_USE_DB=true
export eSRV_MASTER_IP=192.168.0.254
export eSRV_DB_PATH=ROULETTE_DATA.GDB
export eSRV_DB_SERVER_IP=`cat /etc/sysconfig/network-scripts/ifcfg-eth0 |grep IPADDR|cut -c 8-`
export eSRV_DB_UNAME=SYSDBA
export eSRV_DB_PASS=masteraloha
export eSRV_ROULETTE_IP=192.168.0.0
export eSRV_LICENSED_TO="`cat /RouletteMaster/licensed.to`"

#tako dela event queue na vseh sistemih
export SDL_VIDEODRIVER=dummy

export eSRV_ENABLE_RPC=true
export eSRV_RPC_PORT=6666

#this entries have priority over DB configuration
#export eSRV_SMS_DRIVER=SMS3
#export eSRV_SMS_COM=/dev/ttyNOUSE
#export eSRV_ENABLE_SMS=true


export PROGRAM_FOLDER=/RouletteMaster/
export PROGRAM_FILENAME=roulettemaster
# Check the file is there and is executable.
if [ ! -x $PROGRAM_FOLDER/$PROGRAM_FILENAME ] 
then
	echo $"$PROGRAM_FOLDER/$PROGRAM_FILENAME does not exist or it is not an executable" 
	exit 0
fi

start(){
	if [ -n "$(ps -A |grep $PROGRAM_FILENAME)" ] 
	then
	 	echo $"$PROGRAM_FILENAME is already running" 
		return 0
	fi

	echo -n $"Starting $PROGRAM_FILENAME:     "
	cd $PROGRAM_FOLDER

	#before starting program, we check if a _update file is pending as program update - usefull to update at next reboot
	if [ -e $PROGRAM_FILENAME"_update" ]; then
	    echo
	    echo "    "Updating $PROGRAM_FOLDER/$PROGRAM_FILENAME with file $PROGRAM_FOLDER/$PROGRAM_FILENAME"_update"
	    echo "    "Old version will be renamed to $PROGRAM_FOLDER/$PROGRAM_FILENAME"_old"
	    echo
	    
	    mv -f $PROGRAM_FILENAME $PROGRAM_FILENAME"_old" > /dev/null
	    mv -f $PROGRAM_FILENAME"_update" $PROGRAM_FILENAME > /dev/null
	    chmod ugo+x $PROGRAM_FILENAME
	fi;
	
	echo "`date` Program start..." > /dev/null
	./$PROGRAM_FILENAME > /dev/null &
	RETVAL=$?
	sleep 1
	echo "Done!"
	service roulettesnd start
	return $RETVAL
}

startverbose(){
    if [ -n "$(ps -A |grep $PROGRAM_FILENAME)" ]
    then
	echo $"$PROGRAM_FILENAME is already running"
        return 0
    fi
        
    echo -n $"Starting $PROGRAM_FILENAME:     "
    cd $PROGRAM_FOLDER

    #before starting program, we check if a _update file is pending as program update - usefull to update at next reboot
    if [ -e $PROGRAM_FILENAME"_update" ]; then
	echo
        echo "    "Updating $PROGRAM_FOLDER/$PROGRAM_FILENAME with file $PROGRAM_FOLDER/$PROGRAM_FILENAME"_update"
        echo "    "Old version will be renamed to $PROGRAM_FOLDER/$PROGRAM_FILENAME"_old"
        echo
    
        mv -f $PROGRAM_FILENAME $PROGRAM_FILENAME"_old" > /dev/null
        mv -f $PROGRAM_FILENAME"_update" $PROGRAM_FILENAME > /dev/null
        chmod ugo+x $PROGRAM_FILENAME
    fi;

    echo "`date` Program start..." > /dev/null
    ./$PROGRAM_FILENAME &
    RETVAL=$?
    sleep 1
    echo "Done!"
    service roulettesnd start
    return $RETVAL
}

stop(){
        if [ -z "$(ps -A |grep $PROGRAM_FILENAME)" ] 
	then
	 	echo $"$PROGRAM_FILENAME is not running" 
		return 0
	fi

	service roulettesnd stop
	echo -n $"Stoping $PROGRAM_FILENAME:      "
	echo "`date` Program stop..." > /dev/null
	killall -SIGABRT $PROGRAM_FILENAME &>/dev/null
	RETVAL=$?
	sleep 1
	echo "Done!"
	return $RETVAL
}

kill_instance(){
	if [ -z "$(ps -A |grep $PROGRAM_FILENAME)" ]
	then
	    echo $"$PROGRAM_FILENAME is not running"
	    return 0
	fi
	kill -s 9 `ps -A |grep -m 1 $PROGRAM_FILENAME|cut -c 0-6`
	RETVAL=$?
	echo "$PROGRAM_FILENAME killed!"
	return $RETVAL
}


# See how we were called.
case "$1" in
  start)
	start
	;;	
  starthere)
	startverbose
	;;
  stop) 
	stop
	;;
  restart)
	stop
	start
	;;
  kill)
	kill_instance
	;;
  *)
	echo $"Usage: roulettemaster {start|starthere|restart|stop|kill}"
	exit 1
esac

exit $RETVAL

